package com.game.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import java.util.List;
        import com.game.common.utils.DateUtils;
import com.game.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.game.business.mapper.AppUserAgentMapper;
import com.game.business.domain.AppUserAgent;
import com.game.business.service.IAppUserAgentService;
import com.game.common.annotation.DataSource;
import com.game.common.enums.DataSourceType;

/**
 * 用户代理表Service业务层处理
 *
 * @author game
 * @date 2024-06-25
 */
@Service
public class AppUserAgentServiceImpl extends ServiceImpl<AppUserAgentMapper, AppUserAgent> implements IAppUserAgentService {
    @Autowired
    private AppUserAgentMapper appUserAgentMapper;

    /**
     * 查询用户代理表
     *
     * @param id 用户代理表主键
     * @return 用户代理表
     */
    @Override
    public AppUserAgent selectAppUserAgentById(Long id) {
        return appUserAgentMapper.selectAppUserAgentById(id);
    }

    /**
     * 查询用户代理表列表
     *
     * @param appUserAgent 用户代理表
     * @return 用户代理表
     */
    @Override
    public List<AppUserAgent> selectAppUserAgentList(AppUserAgent appUserAgent) {
        return appUserAgentMapper.selectAppUserAgentList(appUserAgent);
    }

    /**
     * 新增用户代理表
     *
     * @param appUserAgent 用户代理表
     * @return 结果
     */
    @Override
    public int insertAppUserAgent(AppUserAgent appUserAgent) {
                appUserAgent.setCreateTime(DateUtils.getNowDate());
            return appUserAgentMapper.insertAppUserAgent(appUserAgent);
    }

    /**
     * 修改用户代理表
     *
     * @param appUserAgent 用户代理表
     * @return 结果
     */
    @Override
    public int updateAppUserAgent(AppUserAgent appUserAgent) {
                appUserAgent.setUpdateTime(DateUtils.getNowDate());
        return appUserAgentMapper.updateAppUserAgent(appUserAgent);
    }

    /**
     * 批量删除用户代理表
     *
     * @param ids 需要删除的用户代理表主键
     * @return 结果
     */
    @Override
    public int deleteAppUserAgentByIds(Long[] ids) {
        return appUserAgentMapper.deleteAppUserAgentByIds(ids);
    }

    /**
     * 删除用户代理表信息
     *
     * @param id 用户代理表主键
     * @return 结果
     */
    @Override
    public int deleteAppUserAgentById(Long id) {
        return appUserAgentMapper.deleteAppUserAgentById(id);
    }

    /**
     * 统计用户代理人数
     * */
    @Override
    public int countAgent(Long userId, String beginTime, String endTime) {
        LambdaQueryWrapper<AppUserAgent> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(AppUserAgent::getPid,userId);
        if(StringUtils.isNotBlank(beginTime)){
            queryWrapper.ge(AppUserAgent::getCreateTime,beginTime);
        }
        if(StringUtils.isNotBlank(endTime)){
            queryWrapper.le(AppUserAgent::getCreateTime,endTime);
        }
        queryWrapper.eq(AppUserAgent::getAuditStatus,"1");
        return appUserAgentMapper.selectCount(queryWrapper).intValue();
    }
}